<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Sun Apr 26 2020 16:42:18 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed There is no current event loop in thread 'POSTPROCESSORQUEUE-MANUAL' error, using AnyThreadEventLoopPolicy Added thread locking to queue workers
  ([2d457060](https://gitlab-ci-token:sd615zPqKzagHTMGrXEy@git.sickrage.ca/SiCKRAGE/sickrage/commit/2d457060f0db7ebd82b9d252fcb323acf9549f1c))




